@@ -1,6 +1,6 @@
 "dataquality"
 
-__version__ = "v0.8.13"
+__version__ = "v0.8.14"
 
 import os
 import warnings
@@ -35,6 +35,7 @@ from dataquality.core.log import (
     log_dataset,
     log_image_dataset,
     log_model_outputs,
+    log_xgboost,
     set_epoch,
     set_epoch_and_split,
     set_labels_for_run,
@@ -127,6 +128,7 @@ __all__ = [
     "log_data_sample",
     "log_dataset",
     "log_image_dataset",
+    "log_xgboost",
     "get_dq_log_file",
     "build_run_report",
     "register_run_report",
