@@ -1,4 +1,6 @@
+import json
 import os
+from json import JSONDecodeError
 from time import sleep
 from typing import Any, Dict, List, Optional, Tuple, Union
 
@@ -6,7 +8,7 @@ import requests
 from pydantic.types import UUID4
 from requests import Response
 
-from dataquality.core._config import config, url_is_localhost
+from dataquality.core._config import config
 from dataquality.exceptions import GalileoException
 from dataquality.schemas import RequestType, Route
 from dataquality.schemas.dataframe import FileType
@@ -69,6 +71,7 @@ class ApiClient:
         data: Dict = None,
         params: Dict = None,
         header: Dict = None,
+        timeout: Union[int, None] = None,
     ) -> Any:
         """Makes an HTTP request.
 
@@ -78,7 +81,7 @@ class ApiClient:
         self.__check_login()
         header = header or headers(config.token)
         res = RequestType.get_method(request.value)(
-            url, json=body, params=params, headers=header, data=data
+            url, json=body, params=params, headers=header, data=data, timeout=timeout
         )
         self._validate_response(res)
         return res.json()
@@ -374,6 +377,8 @@ class ApiClient:
             run_id=str(run),
             labels=labels,
             tasks=tasks or None,
+            task_type=task_type,
+            xray=False,  # Don't recalculate XRay in process
         )
         res = self.make_request(
             RequestType.POST, url=f"{config.api_url}/{Route.jobs}", body=body
@@ -515,32 +520,37 @@ class ApiClient:
     def get_run_status(
         self, project_name: Optional[str] = None, run_name: Optional[str] = None
     ) -> Dict[str, Any]:
-        if url_is_localhost(config.api_url):
-            raise GalileoException(
-                "You cannot check run status when running the server locally"
-            )
         pid, rid = self._get_project_run_id(
             project_name=project_name, run_name=run_name
         )
-        list_jobs_url = f"{config.api_url}/{Route.content_path(pid, rid)}/{Route.jobs}"
-        jobs = self.make_request(RequestType.GET, list_jobs_url)
-        sorted_jobs = sorted(jobs, key=lambda row: row["created_at"], reverse=True)
-        return sorted_jobs[0] if sorted_jobs else {}
+        job_url = f"{config.api_url}/{Route.content_path(pid, rid)}/{Route.latest_job}"
+        job = self.make_request(RequestType.GET, job_url)
+        return job or {}
 
     def wait_for_run(
         self, project_name: Optional[str] = None, run_name: Optional[str] = None
     ) -> None:
         print("Waiting for job...")
+        last_progress_message = ""
         while True:
             job = self.get_run_status(project_name=project_name, run_name=run_name)
             if job.get("status") == "completed":
                 print(f"Done! Job finished with status {job.get('status')}")
                 return
             elif job.get("status") == "failed":
+                # Try to properly format the stacktrace
+                try:
+                    err = json.loads(job.get("error_message", ""))
+                except JSONDecodeError:
+                    err = job.get("error_message")
                 raise GalileoException(
-                    f"It seems your run failed with status "
-                    f"{job.get('status')}, error {job.get('error_message')}"
-                )
+                    f"It seems your run failed with error\n{err}"
+                ) from None
+            elif job.get("status") == "in_progress" and job.get("progress_message"):
+                if last_progress_message != job["progress_message"]:
+                    print(f"\t{job['progress_message']}")
+                    last_progress_message = job["progress_message"]
+                sleep(2)
             elif not job or job.get("status") in ["unstarted", "in_progress"]:
                 sleep(2)
             else:
@@ -723,6 +733,21 @@ class ApiClient:
         params = {"inference_name": inference_name}
         self._export_dataframe_request(url, body, params, file_name)
 
+    def send_analytics(
+        self,
+        project_id: str = "UNKNOWN",
+        run_id: str = "UNKNOWN",
+        run_task_type: str = "UNKNOWN",
+        payload: Dict = {},
+        scope: str = "dq",
+    ) -> Dict:
+        """Creates a project given a name and returns the project information"""
+        path = Route.content_path(project_id, run_id)
+        body = {**payload, "run_task_type": run_task_type}
+        url = f"{config.api_url}/{path}/{Route.ampli}/{scope}"
+
+        return self.make_request(RequestType.POST, url, body=body, timeout=1)
+
     def _export_dataframe_request(
         self, url: str, body: Dict, params: Dict, file_name: str
     ) -> None:
@@ -733,3 +758,30 @@ class ApiClient:
             with open(file_name, "wb") as f:
                 for chunk in r.iter_content(chunk_size=8192):
                     f.write(chunk)
+
+    def notify_email(
+        self, data: Dict, template: str, emails: Optional[List[str]] = None
+    ) -> None:
+        self.make_request(
+            RequestType.POST,
+            url=f"{config.api_url}/{Route.notify}",
+            body={"data": data, "template": template, "emails": emails},
+        )
+
+    def get_splits(self, project_id: UUID4, run_id: UUID4) -> Dict:
+        return self.make_request(
+            RequestType.GET,
+            url=(
+                f"{config.api_url}/{Route.projects}/{project_id}/{Route.runs}/{run_id}/"
+                f"{Route.splits}"
+            ),
+        )
+
+    def get_inference_names(self, project_id: UUID4, run_id: UUID4) -> Dict:
+        return self.make_request(
+            RequestType.GET,
+            url=(
+                f"{config.api_url}/{Route.projects}/{project_id}/{Route.runs}/{run_id}/"
+                f"{Route.inference_names}"
+            ),
+        )
