@@ -7,15 +7,20 @@ import numpy as np
 from scipy.special import expit, softmax
 
 from dataquality import config
+from dataquality.analytics import Analytics
+from dataquality.clients.api import ApiClient
 from dataquality.exceptions import GalileoException, GalileoWarning, LogBatchError
 from dataquality.loggers.base_logger import BaseGalileoLogger
 from dataquality.loggers.data_logger import BaseGalileoDataLogger
 from dataquality.schemas.split import Split
 from dataquality.schemas.task_type import TaskType
+from dataquality.utils.ampli import AmpliMetric
 from dataquality.utils.dq_logger import get_dq_logger
 from dataquality.utils.thread_pool import ThreadPoolManager
 from dataquality.utils.vaex import _save_hdf5_file
 
+analytics = Analytics(ApiClient, config)  # type: ignore
+
 
 class BaseGalileoModelLogger(BaseGalileoLogger):
     def __init__(
@@ -80,6 +85,11 @@ class BaseGalileoModelLogger(BaseGalileoLogger):
                 f"{repr(e)}"
             )
             warnings.warn(err_msg)
+            try:
+                analytics.set_config(config)
+                analytics.capture_exception(e, AmpliMetric.dq_validation_error)
+            except Exception:
+                pass
             self.logger_config.exception = err_msg
 
     def log(self) -> None:
@@ -118,16 +128,6 @@ class BaseGalileoModelLogger(BaseGalileoLogger):
 
     def set_split_epoch(self) -> None:
         super().set_split_epoch()
-        # Inference split must have inference name
-        if self.split == Split.inference and self.inference_name is None:
-            if self.logger_config.cur_inference_name is not None:
-                self.inference_name = self.logger_config.cur_inference_name
-            else:
-                raise GalileoException(
-                    "For inference split you must either log an inference name "
-                    "or set it before logging. Use `dataquality.set_split` to set"
-                    "inference_name"
-                )
 
         # Non-inference split must have an epoch
         if self.split != Split.inference and self.epoch is None:
