@@ -1,26 +1,30 @@
 import os
-import threading
+import sys
 from typing import Dict, List
 
 import h5py
 import numpy as np
+import pyarrow as pa
 import vaex
 from vaex.arrow.convert import arrow_string_array_from_buffers as convert_bytes
 from vaex.dataframe import DataFrame
 
 from dataquality.exceptions import GalileoException
 from dataquality.loggers.base_logger import BaseLoggerAttributes
-from dataquality.schemas.split import Split
 from dataquality.utils import tqdm
 from dataquality.utils.hdf5_store import HDF5_STORE, HDF5Store
 from dataquality.utils.helpers import galileo_verbose_logging
+from dataquality.utils.thread_pool import lock
 
-lock = threading.Lock()
+# To decide between "all-MiniLM-L6-v2" or "all-mpnet-base-v2"
+# https://www.sbert.net/docs/pretrained_models.html#model-overview
+GALILEO_DATA_EMBS_ENCODER = "GALILEO_DATA_EMBS_ENCODER"
+DEFAULT_DATA_EMBS_MODEL = "all-MiniLM-L6-v2"
 
 
 def _save_hdf5_file(location: str, file_name: str, data: Dict) -> None:
     """
-    Helper function to save a dictionary as an hdf5 file
+    Helper function to save a dictionary as an hdf5 file that can be read by vaex
     """
     if not os.path.isdir(location):
         with lock:
@@ -88,9 +92,10 @@ def validate_unique_ids(df: DataFrame, epoch_or_inf_name: str) -> None:
         epoch_or_inf_value, split = df[[epoch_or_inf_name, "split"]][0]
         dups = get_dup_ids(df)
         exc = (
-            f"It seems as though you do not have unique ids in split {split}. If "
+            f"It seems your logged output data has duplicate ids in split {split}. If "
             f"you've re-run a block of code or notebook cell that logs model outputs, "
-            f"that could be the cause. Try reinitializing with `dq.init` to clear your "
+            f"that could be the cause. It could also be a misconfiguration in your "
+            f"model architecture. Try reinitializing with `dq.init` to clear your "
             f"local environment, and then logging your data again. "
         )
         if galileo_verbose_logging():
@@ -101,42 +106,6 @@ def validate_unique_ids(df: DataFrame, epoch_or_inf_name: str) -> None:
         raise GalileoException(exc)
 
 
-def validate_ids_for_slice(df: DataFrame, col_name: str, value: str) -> None:
-    """Helper function to validate a slice of the logged df has unique ids
-
-    Slice data on the value of a vaex df column. This helper function only
-    validates ids for slice equal to "epoch" or "inference_name".
-
-    Fail gracefully on invalid ids or invalid slice
-    """
-    sliced_df = df[df[col_name] == value]
-    if col_name == "inference_name":
-        validate_unique_ids(sliced_df, "inference_name")
-    elif col_name == "split":
-        validate_unique_ids(sliced_df, "split")
-    else:
-        raise GalileoException(
-            f"Invalid data slice. Column: {col_name}, Value: {value}"
-        )
-
-
-def validate_ids_for_df(df: DataFrame) -> None:
-    """Helper function to validate the logged df has no duplicates
-
-    For each split and inference name, validate that the sliced
-    df has unique ids.
-
-    Raises GalileoExcpetion on invalid df
-    """
-    for split in df["split"].unique():
-        if split == Split.inference:
-            inf_df = df[df["split"] == split]
-            for inference_name in inf_df["inference_name"].unique():
-                validate_ids_for_slice(inf_df, "inference_name", inference_name)
-        else:
-            validate_ids_for_slice(df, "split", split)
-
-
 def get_dup_ids(df: DataFrame) -> List:
     """Gets the list of duplicate IDs in a dataframe, if any"""
     df_copy = df.copy()
@@ -149,9 +118,8 @@ def _valid_prob_col(col: str) -> bool:
         col.endswith("id")
         or "gold" in col
         or "pred" in col
-        or col.startswith("prob")
+        or "prob" in col  # encapsulates prob, conf_prob, and loss_prob
         or col.startswith("span")
-        or col.startswith("data_")
         or col.startswith("galileo")
     )
 
@@ -192,7 +160,12 @@ def concat_hdf5_files(location: str, prob_only: bool) -> List[str]:
             str_cols.append(col)
         stores[col] = HDF5Store(f"{location}/{HDF5_STORE}", group, shape, dtype=dtype)
 
-    for file in tqdm(files, leave=False, desc="Combining batches for upload"):
+    for file in tqdm(
+        files,
+        leave=False,
+        desc="Processing data for upload",
+        file=sys.stdout,
+    ):
         fname = f"{location}/{file}"
         with h5py.File(fname, "r") as f:
             dset = f["table"]["columns"]
@@ -217,12 +190,17 @@ def concat_hdf5_files(location: str, prob_only: bool) -> List[str]:
 
 def drop_empty_columns(df: DataFrame) -> DataFrame:
     """Drops any columns that have no values"""
+    if len(df) == 0:
+        return df
+    df_copy = df.copy()
     cols = df.get_column_names()
     # Don't need to check the default columns, they've already been validated
     cols = [c for c in cols if c not in list(BaseLoggerAttributes)]
     col_counts = df.count(cols)
     empty_cols = [col for col, col_count in zip(cols, col_counts) if col_count == 0]
-    return df.drop(*empty_cols) if empty_cols else df
+    for c in empty_cols:
+        df_copy = df_copy.drop(c)
+    return df_copy
 
 
 def filter_df(df: DataFrame, col_name: str, value: str) -> DataFrame:
@@ -243,3 +221,23 @@ def rename_df(df: DataFrame, columns: Dict) -> DataFrame:
     for old, new in columns.items():
         df_copy.rename(old, new)
     return df_copy
+
+
+def create_data_embs(df: DataFrame) -> DataFrame:
+    """Runs sentence transformer on raw text to get off the shelf data embeddings"""
+    # This import takes up to 25 seconds, so we don't want to eagerly import it
+    import transformers
+    from sentence_transformers import SentenceTransformer
+
+    transformers.logging.disable_progress_bar()
+    sentence_encoder = os.getenv(GALILEO_DATA_EMBS_ENCODER, DEFAULT_DATA_EMBS_MODEL)
+    data_model = SentenceTransformer(sentence_encoder)
+    df_copy = df.copy()
+
+    @vaex.register_function()
+    def apply_sentence_transformer(text: pa.array) -> np.ndarray:
+        return data_model.encode(text.to_pylist(), show_progress_bar=False)
+
+    df_copy["emb"] = df_copy["text"].apply_sentence_transformer()
+    transformers.logging.enable_progress_bar()
+    return df_copy[["id", "emb"]]
