@@ -1,15 +1,15 @@
 import os
 import shutil
-from typing import Any, Callable, Dict, Generator, List
+from typing import Any, Callable, Dict, Generator, List, Optional
 from uuid import UUID
 
 import pytest
 import requests
-import spacy
+from transformers import AutoModelForSequenceClassification, AutoTokenizer
 from vaex.dataframe import DataFrame
 
 import dataquality
-from dataquality import AggregateFunction, Condition, Operator, config
+from dataquality import AggregateFunction, Condition, ConditionFilter, Operator, config
 from dataquality.clients import objectstore
 from dataquality.loggers import BaseGalileoLogger
 from dataquality.schemas.task_type import TaskType
@@ -27,7 +27,20 @@ TEST_PATH = f"{LOCATION}/{TEST_STORE_DIR}"
 SPLITS = ["training", "test"]
 SUBDIRS = ["data", "emb", "prob"]
 
-spacy.util.fix_random_seed()
+
+# Load models locally
+HF_TEST_BERT_PATH = "hf-internal-testing/tiny-random-distilbert"
+LOCAL_MODEL_PATH = "tmp/testing-random-distilbert-sq"
+try:
+    tokenizer = AutoTokenizer.from_pretrained(LOCAL_MODEL_PATH)
+except Exception:
+    tokenizer = AutoTokenizer.from_pretrained(HF_TEST_BERT_PATH)
+    tokenizer.save_pretrained(LOCAL_MODEL_PATH)
+try:
+    model = AutoModelForSequenceClassification.from_pretrained(LOCAL_MODEL_PATH)
+except Exception:
+    model = AutoModelForSequenceClassification.from_pretrained(HF_TEST_BERT_PATH)
+    model.save_pretrained(LOCAL_MODEL_PATH)
 
 
 @pytest.fixture(autouse=True)
@@ -40,7 +53,8 @@ def disable_network_calls(request, monkeypatch):
         """Unless it's a mocked call to healthcheck, disable network access"""
         if "healthcheck" in url:
             return MockResponse(
-                json_data={"minimum_dq_version": "0.0.0"}, status_code=200
+                json_data={"minimum_dq_version": "0.0.0", "api_version": "100.0.0"},
+                status_code=200,
             )
         raise RuntimeError("Network access not allowed during testing!")
 
@@ -50,7 +64,7 @@ def disable_network_calls(request, monkeypatch):
 @pytest.fixture(scope="function")
 def cleanup_after_use() -> Generator:
     for task_type in list(TaskType):
-        dataquality.get_model_logger(task_type).logger_config.reset()
+        dataquality.get_data_logger(task_type).logger_config.reset()
     try:
         if os.path.isdir(BaseGalileoLogger.LOG_FILE_DIR):
             shutil.rmtree(BaseGalileoLogger.LOG_FILE_DIR)
@@ -67,7 +81,7 @@ def cleanup_after_use() -> Generator:
         if os.path.exists(DQ_LOG_FILE_LOCATION):
             shutil.rmtree(DQ_LOG_FILE_LOCATION)
         for task_type in list(TaskType):
-            dataquality.get_model_logger(task_type).logger_config.reset()
+            dataquality.get_data_logger(task_type).logger_config.reset()
 
 
 @pytest.fixture()
@@ -93,11 +107,8 @@ def set_test_config(
 
 
 @pytest.fixture()
-def statuses_response() -> Dict[str, List]:
-    return [
-        {"job_id": "1", "status": "in_progress", "created_at": "2022-02-20"},
-        {"job_id": "2", "status": "completed", "created_at": "2022-02-24"},
-    ]
+def statuses_response() -> Dict[str, str]:
+    return {"job_id": "2", "status": "completed", "created_at": "2022-02-24"}
 
 
 @pytest.fixture()
@@ -126,13 +137,23 @@ def input_data() -> Callable:
 
 
 @pytest.fixture()
-def condition() -> Condition:
-    return Condition(
-        agg=AggregateFunction.avg,
-        metric="confidence",
-        operator=Operator.lt,
-        threshold=0.3,
-    )
+def test_condition() -> Callable:
+    def curry(
+        agg: AggregateFunction = AggregateFunction.avg,
+        metric: Optional[str] = "confidence",
+        operator: Operator = Operator.lt,
+        threshold: float = 0.5,
+        filters: Optional[List[ConditionFilter]] = [],
+    ) -> Condition:
+        return Condition(
+            agg=agg,
+            metric=metric,
+            operator=operator,
+            threshold=threshold,
+            filters=filters,
+        )
+
+    return curry
 
 
 def patch_object_upload(self: Any, df: DataFrame, object_name: str) -> None:
